@@ -1,24 +1,19 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import argparse
+import io
 import logging
+import os
 from functools import wraps
 
 import simplejson
-import six
-from builtins import str
 from klein import Klein
 from twisted.internet import reactor, threads
 from twisted.internet.defer import inlineCallbacks, returnValue
 
-from rasa_nlu import utils, config
+from rasa_nlu import config, utils
+import rasa_nlu.cli.server as cli
 from rasa_nlu.config import RasaNLUModelConfig
 from rasa_nlu.data_router import (
-    DataRouter, InvalidProjectError,
-    MaxTrainingError)
+    DataRouter, InvalidProjectError, MaxTrainingError)
 from rasa_nlu.model import MINIMUM_COMPATIBLE_VERSION
 from rasa_nlu.train import TrainingException
 from rasa_nlu.utils import json_to_string, read_endpoints
@@ -29,73 +24,7 @@ logger = logging.getLogger(__name__)
 
 def create_argument_parser():
     parser = argparse.ArgumentParser(description='parse incoming text')
-
-    parser.add_argument('-e', '--emulate',
-                        choices=['wit', 'luis', 'dialogflow'],
-                        help='which service to emulate (default: None i.e. use'
-                             ' simple built in format)')
-    parser.add_argument('-P', '--port',
-                        type=int,
-                        default=5000,
-                        help='port on which to run server')
-    parser.add_argument('--pre_load',
-                        nargs='+',
-                        default=[],
-                        help='Preload models into memory before starting the '
-                             'server. \nIf given `all` as input all the models '
-                             'will be loaded.\nElse you can specify a list of '
-                             'specific project names.\nEg: python -m '
-                             'rasa_nlu.server --pre_load project1 --path projects '
-                             '-c config.yaml')
-    parser.add_argument('-t', '--token',
-                        help="auth token. If set, reject requests which don't "
-                             "provide this token as a query parameter")
-    parser.add_argument('-w', '--write',
-                        help='file where logs will be saved')
-    parser.add_argument('--path',
-                        required=True,
-                        help="working directory of the server. Models are"
-                             "loaded from this directory and trained models "
-                             "will be saved here.")
-    parser.add_argument('--cors',
-                        nargs="*",
-                        help='List of domain patterns from where CORS '
-                             '(cross-origin resource sharing) calls are '
-                             'allowed. The default value is `[]` which '
-                             'forbids all CORS requests.')
-
-    parser.add_argument('--max_training_processes',
-                        type=int,
-                        default=1,
-                        help='Number of processes used to handle training '
-                             'requests. Increasing this value will have a '
-                             'great impact on memory usage. It is '
-                             'recommended to keep the default value.')
-    parser.add_argument('--num_threads',
-                        type=int,
-                        default=1,
-                        help='Number of parallel threads to use for '
-                             'handling parse requests.')
-    parser.add_argument('--endpoints',
-                        help='Configuration file for the model server as a yaml file')
-    parser.add_argument('--wait_time_between_pulls',
-                        type=int,
-                        default=10,
-                        help='Wait time in seconds between NLU model server'
-                             'queries.')
-    parser.add_argument('--response_log',
-                        help='Directory where logs will be saved '
-                             '(containing queries and responses).'
-                             'If set to ``null`` logging will be disabled.')
-    parser.add_argument('--storage',
-                        help='Set the remote location where models are stored. '
-                             'E.g. on AWS. If nothing is configured, the '
-                             'server will only serve the models that are '
-                             'on disk in the configured `path`.')
-    parser.add_argument('-c', '--config',
-                        help="Default model configuration file used for "
-                             "training.")
-
+    cli.add_server_arguments(parser)
     utils.add_logging_option_arguments(parser)
 
     return parser
@@ -114,16 +43,14 @@ def check_cors(f):
             if '*' in self.cors_origins:
                 request.setHeader('Access-Control-Allow-Origin', '*')
                 request.setHeader(
-                    'Access-Control-Allow-Headers',
-                    'Content-Type')
+                    'Access-Control-Allow-Headers', 'Content-Type')
                 request.setHeader(
                     'Access-Control-Allow-Methods',
                     'POST, GET, OPTIONS, PUT, DELETE')
             elif origin in self.cors_origins:
                 request.setHeader('Access-Control-Allow-Origin', origin)
                 request.setHeader(
-                    'Access-Control-Allow-Headers',
-                    'Content-Type')
+                    'Access-Control-Allow-Headers', 'Content-Type')
                 request.setHeader(
                     'Access-Control-Allow-Methods',
                     'POST, GET, OPTIONS, PUT, DELETE')
@@ -146,10 +73,7 @@ def requires_auth(f):
     def decorated(*args, **kwargs):
         self = args[0]
         request = args[1]
-        if six.PY3:
-            token = request.args.get(b'token', [b''])[0].decode("utf8")
-        else:
-            token = str(request.args.get('token', [''])[0])
+        token = request.args.get(b'token', [b''])[0].decode("utf8")
         if self.access_token is None or token == self.access_token:
             return f(*args, **kwargs)
         request.setResponseCode(401)
@@ -159,9 +83,8 @@ def requires_auth(f):
 
 
 def decode_parameters(request):
-    """Make sure all the parameters have the same encoding.
+    """Make sure all the parameters have the same encoding."""
 
-    Ensures  py2 / py3 compatibility."""
     return {
         key.decode('utf-8', 'strict'): value[0].decode('utf-8', 'strict')
         for key, value in request.args.items()}
@@ -175,7 +98,7 @@ def parameter_or_default(request, name, default=None):
 
 
 def dump_to_data_file(data):
-    if isinstance(data, six.string_types):
+    if isinstance(data, str):
         data_string = data
     else:
         data_string = utils.json_to_string(data)
@@ -201,7 +124,7 @@ class RasaNLU(object):
         self._configure_logging(loglevel, logfile)
 
         self.default_model_config = self._load_default_config(
-                default_config_path)
+            default_config_path)
 
         self.data_router = data_router
         self._testing = testing
@@ -238,7 +161,7 @@ class RasaNLU(object):
             request_params = decode_parameters(request)
         else:
             request_params = simplejson.loads(
-                    request.content.read().decode('utf-8', 'strict'))
+                request.content.read().decode('utf-8', 'strict'))
 
         if 'query' in request_params:
             request_params['q'] = request_params.pop('query')
@@ -246,7 +169,7 @@ class RasaNLU(object):
         if 'q' not in request_params:
             request.setResponseCode(404)
             dumped = json_to_string(
-                    {"error": "Invalid parse parameter specified"})
+                {"error": "Invalid parse parameter specified"})
             returnValue(dumped)
         else:
             data = self.data_router.extract(request_params)
@@ -254,7 +177,7 @@ class RasaNLU(object):
                 request.setResponseCode(200)
                 response = yield (self.data_router.parse(data) if self._testing
                                   else threads.deferToThread(
-                        self.data_router.parse, data))
+                    self.data_router.parse, data))
                 returnValue(json_to_string(response))
             except InvalidProjectError as e:
                 request.setResponseCode(404)
@@ -272,8 +195,8 @@ class RasaNLU(object):
 
         request.setHeader('Content-Type', 'application/json')
         return json_to_string(
-                {'version': __version__,
-                 'minimum_compatible_version': MINIMUM_COMPATIBLE_VERSION}
+            {'version': __version__,
+             'minimum_compatible_version': MINIMUM_COMPATIBLE_VERSION}
         )
 
     @app.route("/status", methods=['GET', 'OPTIONS'])
@@ -332,12 +255,11 @@ class RasaNLU(object):
         else:
             return content_type[0]
 
-    @app.route("/train", methods=['POST', 'OPTIONS'])
+    @app.route("/train", methods=['POST', 'OPTIONS'], branch=True)
     @requires_auth
     @check_cors
     @inlineCallbacks
     def train(self, request):
-
         # if not set will use the default project name, e.g. "default"
         project = parameter_or_default(request, "project", default=None)
         # if set will not generate a model name but use the passed one
@@ -345,22 +267,26 @@ class RasaNLU(object):
 
         try:
             model_config, data = self.extract_data_and_config(request)
+
         except Exception as e:
             request.setResponseCode(400)
             returnValue(json_to_string({"error": "{}".format(e)}))
 
         data_file = dump_to_data_file(data)
 
-        request.setHeader('Content-Type', 'application/json')
+        request.setHeader('Content-Type', 'application/zip')
 
         try:
             request.setResponseCode(200)
+            request.setHeader("Content-Disposition", "attachment")
+            path_to_model = yield self.data_router.start_train_process(
+                data_file, project,
+                RasaNLUModelConfig(model_config), model_name)
+            zipped_path = utils.zip_folder(path_to_model)
+
+            zip_content = io.open(zipped_path, 'r+b').read()
+            return returnValue(zip_content)
 
-            response = yield self.data_router.start_train_process(
-                    data_file, project,
-                    RasaNLUModelConfig(model_config), model_name)
-            returnValue(json_to_string({'info': 'new model trained',
-                                        'model': response}))
         except MaxTrainingError as e:
             request.setResponseCode(403)
             returnValue(json_to_string({"error": "{}".format(e)}))
@@ -407,9 +333,8 @@ class RasaNLU(object):
         try:
             request.setResponseCode(200)
             response = self.data_router.unload_model(
-                    params.get('project',
-                               RasaNLUModelConfig.DEFAULT_PROJECT_NAME),
-                    params.get('model')
+                params.get('project', RasaNLUModelConfig.DEFAULT_PROJECT_NAME),
+                params.get('model')
             )
             return simplejson.dumps(response)
         except Exception as e:
@@ -418,23 +343,36 @@ class RasaNLU(object):
             return simplejson.dumps({"error": "{}".format(e)})
 
 
-if __name__ == '__main__':
-    # Running as standalone python application
-    cmdline_args = create_argument_parser().parse_args()
+def get_token(_clitoken: str) -> str:
+    _envtoken = os.environ.get("RASA_NLU_TOKEN")
 
-    utils.configure_colored_logging(cmdline_args.loglevel)
-    pre_load = cmdline_args.pre_load
+    if _clitoken and _envtoken:
+        raise Exception(
+            "RASA_NLU_TOKEN is set both with the -t option,"
+            " with value `{}`, and with an environment variable, "
+            "with value `{}`. "
+            "Please set the token with just one method "
+            "to avoid unexpected behaviours.".format(
+                _clitoken, _envtoken))
 
-    _endpoints = read_endpoints(cmdline_args.endpoints)
+    token = _clitoken or _envtoken
+    return token
+
+
+def main(args):
+    utils.configure_colored_logging(args.loglevel)
+    pre_load = args.pre_load
+
+    _endpoints = read_endpoints(args.endpoints)
 
     router = DataRouter(
-            cmdline_args.path,
-            cmdline_args.max_training_processes,
-            cmdline_args.response_log,
-            cmdline_args.emulate,
-            cmdline_args.storage,
-            model_server=_endpoints.model,
-            wait_time_between_pulls=cmdline_args.wait_time_between_pulls
+        args.path,
+        args.max_training_processes,
+        args.response_log,
+        args.emulate,
+        args.storage,
+        model_server=_endpoints.model,
+        wait_time_between_pulls=args.wait_time_between_pulls
     )
     if pre_load:
         logger.debug('Preloading....')
@@ -443,14 +381,20 @@ if __name__ == '__main__':
         router._pre_load(pre_load)
 
     rasa = RasaNLU(
-            router,
-            cmdline_args.loglevel,
-            cmdline_args.write,
-            cmdline_args.num_threads,
-            cmdline_args.token,
-            cmdline_args.cors,
-            default_config_path=cmdline_args.config
+        router,
+        args.loglevel,
+        args.write,
+        args.num_threads,
+        get_token(cmdline_args.token),
+        args.cors,
+        default_config_path=args.config
     )
 
-    logger.info('Started http server on port %s' % cmdline_args.port)
-    rasa.app.run('0.0.0.0', cmdline_args.port)
+    logger.info('Started http server on port %s' % args.port)
+    rasa.app.run('0.0.0.0', args.port)
+
+
+if __name__ == '__main__':
+    # Running as standalone python application
+    cmdline_args = create_argument_parser().parse_args()
+    main(cmdline_args)
