@@ -1,10 +1,6 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
 from rasa_nlu.training_data.formats.dialogflow import DialogflowReader
 from rasa_nlu.training_data.formats.luis import LuisReader
-from rasa_nlu.training_data.formats.wit import WitReader
-from rasa_nlu.training_data.formats.markdown import MarkdownWriter, MarkdownReader
+from rasa_nlu.training_data.formats.markdown import (
+    MarkdownReader, MarkdownWriter)
 from rasa_nlu.training_data.formats.rasa import RasaReader, RasaWriter
+from rasa_nlu.training_data.formats.wit import WitReader
