@@ -1,21 +1,20 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import logging
+import typing
+from typing import Any, Dict, Text
 
-from rasa_nlu.training_data import Message, TrainingData
 from rasa_nlu.training_data.formats.readerwriter import JsonTrainingDataReader
 
+if typing.TYPE_CHECKING:
+    from rasa_nlu.training_data import Message, TrainingData
+
 logger = logging.getLogger(__name__)
 
 
 class WitReader(JsonTrainingDataReader):
 
-    def read_from_json(self, js, **kwargs):
-        # type: (Text, Any) -> TrainingData
+    def read_from_json(self, js: Dict[Text, Any], **kwargs: Any):
         """Loads training data stored in the WIT.ai data format."""
+        from rasa_nlu.training_data import Message, TrainingData
 
         training_examples = []
 
@@ -32,7 +31,7 @@ class WitReader(JsonTrainingDataReader):
                         if ("start" in e and "end" in e and
                             e["entity"] != 'intent')]
             for e in entities:
-                # for some reason wit adds additional quotes around entity values
+                # for some reason wit adds additional quotes around entities
                 e["value"] = e["value"].strip("\"")
 
             data = {}
