@@ -1,8 +1,3 @@
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import errno
 import glob
 import io
@@ -12,16 +7,12 @@ import os
 import re
 import tempfile
 from collections import namedtuple
-from typing import List, Any
-from typing import Optional
-from typing import Text
+from typing import Any, Callable, Dict, List, Optional, Text, Type
 
 import requests
-import simplejson
-import six
 import ruamel.yaml as yaml
-from builtins import str
-from future.utils import PY3
+import simplejson
+from requests import Response
 from requests.auth import HTTPBasicAuth
 
 
@@ -30,25 +21,24 @@ def add_logging_option_arguments(parser, default=logging.WARNING):
 
     # arguments for logging configuration
     parser.add_argument(
-            '--debug',
-            help="Print lots of debugging statements. "
-                 "Sets logging level to DEBUG",
-            action="store_const",
-            dest="loglevel",
-            const=logging.DEBUG,
-            default=default,
+        '--debug',
+        help="Print lots of debugging statements. "
+             "Sets logging level to DEBUG",
+        action="store_const",
+        dest="loglevel",
+        const=logging.DEBUG,
+        default=default,
     )
     parser.add_argument(
-            '-v', '--verbose',
-            help="Be verbose. Sets logging level to INFO",
-            action="store_const",
-            dest="loglevel",
-            const=logging.INFO,
+        '-v', '--verbose',
+        help="Be verbose. Sets logging level to INFO",
+        action="store_const",
+        dest="loglevel",
+        const=logging.INFO,
     )
 
 
-def relative_normpath(f, path):
-    # type: (Optional[Text], Text) -> Optional[Text]
+def relative_normpath(f: Optional[Text], path: Text) -> Optional[Text]:
     """Return the path of file relative to `path`."""
 
     if f is not None:
@@ -57,8 +47,7 @@ def relative_normpath(f, path):
         return None
 
 
-def create_dir(dir_path):
-    # type: (Text) -> None
+def create_dir(dir_path: Text) -> None:
     """Creates a directory and its super paths.
 
     Succeeds even if the path already exists."""
@@ -71,8 +60,7 @@ def create_dir(dir_path):
             raise
 
 
-def create_dir_for_file(file_path):
-    # type: (Text) -> None
+def create_dir_for_file(file_path: Text) -> None:
     """Creates any missing parent directories of this files path."""
 
     try:
@@ -83,14 +71,13 @@ def create_dir_for_file(file_path):
             raise
 
 
-def list_directory(path):
-    # type: (Text) -> List[Text]
+def list_directory(path: Text) -> List[Text]:
     """Returns all files and folders excluding hidden files.
 
     If the path points to a file, returns the file. This is a recursive
     implementation returning files in any depth of the path."""
 
-    if not isinstance(path, six.string_types):
+    if not isinstance(path, str):
         raise ValueError("`resource_name` must be a string type. "
                          "Got `{}` instead".format(type(path)))
 
@@ -108,8 +95,7 @@ def list_directory(path):
                          "".format(os.path.abspath(path)))
 
 
-def list_files(path):
-    # type: (Text) -> List[Text]
+def list_files(path: Text) -> List[Text]:
     """Returns all files excluding hidden files.
 
     If the path points to a file, returns the file."""
@@ -117,8 +103,7 @@ def list_files(path):
     return [fn for fn in list_directory(path) if os.path.isfile(fn)]
 
 
-def list_subdirectories(path):
-    # type: (Text) -> List[Text]
+def list_subdirectories(path: Text) -> List[Text]:
     """Returns all folders excluding hidden files.
 
     If the path points to a file, returns an empty list."""
@@ -128,7 +113,7 @@ def list_subdirectories(path):
             if os.path.isdir(fn)]
 
 
-def lazyproperty(fn):
+def lazyproperty(fn: Callable) -> Any:
     """Allows to avoid recomputing a property over and over.
 
     The result gets stored in a local var. Computation of the property
@@ -146,11 +131,11 @@ def lazyproperty(fn):
     return _lazyprop
 
 
-def list_to_str(l, delim=", ", quote="'"):
+def list_to_str(l: List[Text], delim: Text = ", ", quote: Text = "'") -> Text:
     return delim.join([quote + e + quote for e in l])
 
 
-def ordered(obj):
+def ordered(obj: Any) -> Any:
     if isinstance(obj, dict):
         return sorted((k, ordered(v)) for k, v in obj.items())
     if isinstance(obj, list):
@@ -159,12 +144,12 @@ def ordered(obj):
         return obj
 
 
-def module_path_from_object(o):
+def module_path_from_object(o: Any) -> Text:
     """Returns the fully qualified class path of the instantiated object."""
     return o.__class__.__module__ + "." + o.__class__.__name__
 
 
-def class_from_module_path(module_path):
+def class_from_module_path(module_path: Text) -> Type[Any]:
     """Given the module name and path of a class, tries to retrieve the class.
 
     The loaded class can be used to instantiate new objects. """
@@ -180,34 +165,32 @@ def class_from_module_path(module_path):
         return globals()[module_path]
 
 
-def json_to_string(obj, **kwargs):
+def json_to_string(obj: Any, **kwargs: Any) -> Text:
     indent = kwargs.pop("indent", 2)
     ensure_ascii = kwargs.pop("ensure_ascii", False)
     return json.dumps(obj, indent=indent, ensure_ascii=ensure_ascii, **kwargs)
 
 
-def write_json_to_file(filename, obj, **kwargs):
-    # type: (Text, Any) -> None
+def write_json_to_file(filename: Text, obj: Any, **kwargs: Any) -> None:
     """Write an object as a json string to a file."""
 
     write_to_file(filename, json_to_string(obj, **kwargs))
 
 
-def write_to_file(filename, text):
-    # type: (Text, Text) -> None
+def write_to_file(filename: Text, text: Text) -> None:
     """Write a text to a file."""
 
     with io.open(filename, 'w', encoding="utf-8") as f:
         f.write(str(text))
 
 
-def read_file(filename, encoding="utf-8-sig"):
+def read_file(filename: Text, encoding: Text = "utf-8-sig") -> Any:
     """Read text from a file."""
     with io.open(filename, encoding=encoding) as f:
         return f.read()
 
 
-def read_json_file(filename):
+def read_json_file(filename: Text) -> Any:
     """Read json from a file."""
     content = read_file(filename)
     try:
@@ -217,7 +200,7 @@ def read_json_file(filename):
                          "{}".format(os.path.abspath(filename), e))
 
 
-def fix_yaml_loader():
+def fix_yaml_loader() -> None:
     """Ensure that any string read by yaml is represented as unicode."""
 
     def construct_yaml_str(self, node):
@@ -230,11 +213,12 @@ def fix_yaml_loader():
                                     construct_yaml_str)
 
 
-def replace_environment_variables():
+def replace_environment_variables() -> None:
     """Enable yaml loader to process the environment variables in the yaml."""
     import re
     import os
 
+    # noinspection RegExpRedundantEscape
     env_var_pattern = re.compile(r"^(.*)\$\{(.*)\}(.*)$")
     yaml.add_implicit_resolver('!env_var', env_var_pattern)
 
@@ -247,7 +231,7 @@ def replace_environment_variables():
     yaml.SafeConstructor.add_constructor(u'!env_var', env_var_constructor)
 
 
-def read_yaml(content):
+def read_yaml(content: Text) -> Any:
     """Parses yaml from a text.
 
      Args:
@@ -260,6 +244,7 @@ def read_yaml(content):
     yaml_parser.version = "1.2"
     yaml_parser.unicode_supplementary = True
 
+    # noinspection PyUnresolvedReferences
     try:
         return yaml_parser.load(content)
     except yaml.scanner.ScannerError as _:
@@ -274,7 +259,7 @@ def read_yaml(content):
         return yaml_parser.load(content)
 
 
-def read_yaml_file(filename):
+def read_yaml_file(filename: Text) -> Any:
     """Parses a yaml file.
 
      Args:
@@ -283,7 +268,11 @@ def read_yaml_file(filename):
     return read_yaml(read_file(filename, "utf-8"))
 
 
-def build_entity(start, end, value, entity_type, **kwargs):
+def build_entity(start: int,
+                 end: int,
+                 value: Text,
+                 entity_type: Text,
+                 **kwargs: Dict[Text, Any]) -> Dict[Text, Any]:
     """Builds a standard entity dictionary.
 
     Adds additional keyword parameters."""
@@ -299,7 +288,7 @@ def build_entity(start, end, value, entity_type, **kwargs):
     return entity
 
 
-def is_model_dir(model_dir):
+def is_model_dir(model_dir: Text) -> bool:
     """Checks if the given directory contains a model and can be safely removed.
 
     specifically checks if the directory has no subdirectories and
@@ -315,7 +304,7 @@ def is_model_dir(model_dir):
     return only_valid_files
 
 
-def is_url(resource_name):
+def is_url(resource_name: Text) -> bool:
     """Return True if string is an http, ftp, or file URL path.
 
     This implementation is the same as the one used by matplotlib"""
@@ -324,7 +313,7 @@ def is_url(resource_name):
     return URL_REGEX.match(resource_name) is not None
 
 
-def remove_model(model_dir):
+def remove_model(model_dir: Text) -> bool:
     """Removes a model directory and all its content."""
     import shutil
     if is_model_dir(model_dir):
@@ -335,42 +324,29 @@ def remove_model(model_dir):
                          "directory".format(model_dir))
 
 
-def as_text_type(t):
-    if isinstance(t, six.text_type):
-        return t
-    else:
-        return six.text_type(t)
-
-
-def configure_colored_logging(loglevel):
+def configure_colored_logging(loglevel: Text) -> None:
     import coloredlogs
     field_styles = coloredlogs.DEFAULT_FIELD_STYLES.copy()
     field_styles['asctime'] = {}
     level_styles = coloredlogs.DEFAULT_LEVEL_STYLES.copy()
     level_styles['debug'] = {}
     coloredlogs.install(
-            level=loglevel,
-            use_chroot=False,
-            fmt='%(asctime)s %(levelname)-8s %(name)s  - %(message)s',
-            level_styles=level_styles,
-            field_styles=field_styles)
+        level=loglevel,
+        use_chroot=False,
+        fmt='%(asctime)s %(levelname)-8s %(name)s  - %(message)s',
+        level_styles=level_styles,
+        field_styles=field_styles)
 
 
-def pycloud_unpickle(file_name):
-    # type: (Text) -> Any
+def pycloud_unpickle(file_name: Text) -> Any:
     """Unpickle an object from file using cloudpickle."""
-    from future.utils import PY2
     import cloudpickle
 
     with io.open(file_name, 'rb') as f:  # pragma: no test
-        if PY2:
-            return cloudpickle.load(f)
-        else:
-            return cloudpickle.load(f, encoding="latin-1")
+        return cloudpickle.load(f, encoding="latin-1")
 
 
-def pycloud_pickle(file_name, obj):
-    # type: (Text, Any) -> None
+def pycloud_pickle(file_name: Text, obj: Any) -> None:
     """Pickle an object to a file using cloudpickle."""
     import cloudpickle
 
@@ -378,39 +354,34 @@ def pycloud_pickle(file_name, obj):
         cloudpickle.dump(obj, f)
 
 
-def create_temporary_file(data, suffix="", mode="w+"):
+def create_temporary_file(data: Any,
+                          suffix: Text = "",
+                          mode: Text = "w+") -> Text:
     """Creates a tempfile.NamedTemporaryFile object for data.
 
     mode defines NamedTemporaryFile's  mode parameter in py3."""
 
-    if PY3:
-        encoding = None if 'b' in mode else 'utf-8'
-        f = tempfile.NamedTemporaryFile(mode=mode, suffix=suffix,
-                                        delete=False, encoding=encoding)
-        f.write(data)
-    else:
-        f = tempfile.NamedTemporaryFile("w+", suffix=suffix,
-                                        delete=False)
-        f.write(data.encode("utf-8"))
+    encoding = None if 'b' in mode else 'utf-8'
+    f = tempfile.NamedTemporaryFile(mode=mode, suffix=suffix,
+                                    delete=False, encoding=encoding)
+    f.write(data)
 
     f.close()
     return f.name
 
 
-def zip_folder(folder):
+def zip_folder(folder: Text) -> Text:
     """Create an archive from a folder."""
     import tempfile
     import shutil
 
+    # WARN: not thread save!
     zipped_path = tempfile.NamedTemporaryFile(delete=False)
     zipped_path.close()
-
-    # WARN: not thread save!
     return shutil.make_archive(zipped_path.name, str("zip"), folder)
 
 
-def concat_url(base, subpath):
-    # type: (Text, Optional[Text]) -> Text
+def concat_url(base: Text, subpath: Optional[Text]) -> Text:
     """Append a subpath to a base url.
 
     Strips leading slashes from the subpath if necessary. This behaves
@@ -429,8 +400,8 @@ def concat_url(base, subpath):
         return base
 
 
-def read_endpoint_config(filename, endpoint_type):
-    # type: (Text, Text) -> Optional[EndpointConfig]
+def read_endpoint_config(filename: Text,
+                         endpoint_type: Text) -> Optional['EndpointConfig']:
     """Read an endpoint configuration file from disk and extract one
 
     config. """
@@ -444,7 +415,7 @@ def read_endpoint_config(filename, endpoint_type):
         return None
 
 
-def read_endpoints(endpoint_file):
+def read_endpoints(endpoint_file: Text) -> 'AvailableEndpoints':
     model = read_endpoint_config(endpoint_file,
                                  endpoint_type="model")
     data = read_endpoint_config(endpoint_file,
@@ -461,8 +432,13 @@ AvailableEndpoints = namedtuple('AvailableEndpoints', 'model data')
 class EndpointConfig(object):
     """Configuration for an external HTTP endpoint."""
 
-    def __init__(self, url, params=None, headers=None, basic_auth=None,
-                 token=None, token_name="token"):
+    def __init__(self,
+                 url: Text,
+                 params: Dict[Text, Any] = None,
+                 headers: Dict[Text, Any] = None,
+                 basic_auth: Dict[Text, Text] = None,
+                 token: Optional[Text] = None,
+                 token_name: Text = "token"):
         self.url = url
         self.params = params if params else {}
         self.headers = headers if headers else {}
@@ -471,11 +447,11 @@ class EndpointConfig(object):
         self.token_name = token_name
 
     def request(self,
-                method="post",  # type: Text
-                subpath=None,  # type: Optional[Text]
-                content_type="application/json",  # type: Optional[Text]
-                **kwargs  # type: Any
-                ):
+                method: Text = "post",
+                subpath: Optional[Text] = None,
+                content_type: Optional[Text] = "application/json",
+                **kwargs: Any
+                ) -> Response:
         """Send a HTTP request to the endpoint.
 
         All additional arguments will get passed through
@@ -518,9 +494,7 @@ class EndpointConfig(object):
 
     @classmethod
     def from_dict(cls, data):
-        return EndpointConfig(
-                data.pop("url"),
-                **data)
+        return EndpointConfig(data.pop("url"), **data)
 
     def __eq__(self, other):
         if isinstance(self, type(other)):
