@@ -1,20 +1,15 @@
 # -*- coding: utf-8 -*-
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
 import os
 import pytest
-from rasa_nlu.config import RasaNLUModelConfig
 
-from tests.conftest import DEFAULT_DATA_PATH
 from rasa_nlu import registry, train
-from rasa_nlu.model import Trainer, Interpreter
+from rasa_nlu.config import RasaNLUModelConfig
+from rasa_nlu.model import Interpreter, Trainer
 from rasa_nlu.train import create_persistor
 from rasa_nlu.training_data import TrainingData
 from tests import utilities
+from tests.conftest import DEFAULT_DATA_PATH
 
 
 def as_pipeline(*components):
@@ -28,31 +23,31 @@ def pipelines_for_tests():
     # generate this automatically.
 
     # first is language followed by list of components
-    return [("en", as_pipeline("nlp_spacy",
-                               "nlp_mitie",
-                               "tokenizer_whitespace",
-                               "tokenizer_mitie",
-                               "tokenizer_spacy",
-                               "intent_featurizer_mitie",
-                               "intent_featurizer_spacy",
-                               "intent_featurizer_ngrams",
-                               "intent_entity_featurizer_regex",
-                               "intent_featurizer_count_vectors",
-                               "ner_mitie",
-                               "ner_crf",
-                               "ner_spacy",
-                               "ner_duckling_http",
-                               "ner_synonyms",
-                               "intent_classifier_keyword",
-                               "intent_classifier_sklearn",
-                               "intent_classifier_mitie",
-                               "intent_classifier_tensorflow_embedding"
+    return [("en", as_pipeline("SpacyNLP",
+                               "MitieNLP",
+                               "WhitespaceTokenizer",
+                               "MitieTokenizer",
+                               "SpacyTokenizer",
+                               "MitieFeaturizer",
+                               "SpacyFeaturizer",
+                               "NGramFeaturizer",
+                               "RegexFeaturizer",
+                               "CountVectorsFeaturizer",
+                               "MitieEntityExtractor",
+                               "CRFEntityExtractor",
+                               "SpacyEntityExtractor",
+                               "DucklingHTTPExtractor",
+                               "EntitySynonymMapper",
+                               "KeywordIntentClassifier",
+                               "SklearnIntentClassifier",
+                               "MitieIntentClassifier",
+                               "EmbeddingIntentClassifier"
                                )),
-            ("zh", as_pipeline("nlp_mitie",
-                               "tokenizer_jieba",
-                               "intent_featurizer_mitie",
-                               "ner_mitie",
-                               "intent_classifier_sklearn",
+            ("zh", as_pipeline("MitieNLP",
+                               "JiebaTokenizer",
+                               "MitieFeaturizer",
+                               "MitieEntityExtractor",
+                               "SklearnIntentClassifier",
                                )),
             ]
 
@@ -73,11 +68,11 @@ def test_all_components_are_in_at_least_one_test_pipeline():
                          list(registry.registered_pipeline_templates.keys()))
 def test_train_model(pipeline_template, component_builder, tmpdir):
     _config = utilities.base_test_conf(pipeline_template)
-    (trained, _, persisted_path) = train.do_train(
-            _config,
-            path=tmpdir.strpath,
-            data=DEFAULT_DATA_PATH,
-            component_builder=component_builder)
+    (trained, _, persisted_path) = train(
+        _config,
+        path=tmpdir.strpath,
+        data=DEFAULT_DATA_PATH,
+        component_builder=component_builder)
     assert trained.pipeline
     loaded = Interpreter.load(persisted_path, component_builder)
     assert loaded.pipeline
@@ -87,23 +82,23 @@ def test_train_model(pipeline_template, component_builder, tmpdir):
 
 @utilities.slowtest
 def test_random_seed(component_builder, tmpdir):
-    '''test if train result is the same for two runs of tf embedding'''
+    """test if train result is the same for two runs of tf embedding"""
 
-    _config = utilities.base_test_conf("tensorflow_embedding")
+    _config = utilities.base_test_conf("supervised_embeddings")
     # set fixed random seed to 1
-    _config.set_component_attr("intent_classifier_tensorflow_embedding", random_seed=1)
+    _config.set_component_attr(5, random_seed=1)
     # first run
-    (trained_a, _, persisted_path_a) = train.do_train(
-            _config,
-            path=tmpdir.strpath + "_a",
-            data=DEFAULT_DATA_PATH,
-            component_builder=component_builder)
+    (trained_a, _, persisted_path_a) = train(
+        _config,
+        path=tmpdir.strpath + "_a",
+        data=DEFAULT_DATA_PATH,
+        component_builder=component_builder)
     # second run
-    (trained_b, _, persisted_path_b) = train.do_train(
-            _config,
-            path=tmpdir.strpath + "_b",
-            data=DEFAULT_DATA_PATH,
-            component_builder=component_builder)
+    (trained_b, _, persisted_path_b) = train(
+        _config,
+        path=tmpdir.strpath + "_b",
+        data=DEFAULT_DATA_PATH,
+        component_builder=component_builder)
     loaded_a = Interpreter.load(persisted_path_a, component_builder)
     loaded_b = Interpreter.load(persisted_path_b, component_builder)
     result_a = loaded_a.parse("hello")["intent"]["confidence"]
@@ -116,11 +111,11 @@ def test_random_seed(component_builder, tmpdir):
 def test_train_model_on_test_pipelines(language, pipeline,
                                        component_builder, tmpdir):
     _config = RasaNLUModelConfig({"pipeline": pipeline, "language": language})
-    (trained, _, persisted_path) = train.do_train(
-            _config,
-            path=tmpdir.strpath,
-            data=DEFAULT_DATA_PATH,
-            component_builder=component_builder)
+    (trained, _, persisted_path) = train(
+        _config,
+        path=tmpdir.strpath,
+        data=DEFAULT_DATA_PATH,
+        component_builder=component_builder)
     assert trained.pipeline
     loaded = Interpreter.load(persisted_path, component_builder)
     assert loaded.pipeline
@@ -132,11 +127,11 @@ def test_train_model_on_test_pipelines(language, pipeline,
 @pytest.mark.parametrize("language, pipeline", pipelines_for_tests())
 def test_train_model_noents(language, pipeline, component_builder, tmpdir):
     _config = RasaNLUModelConfig({"pipeline": pipeline, "language": language})
-    (trained, _, persisted_path) = train.do_train(
-            _config,
-            path=tmpdir.strpath,
-            data="./data/test/demo-rasa-noents.json",
-            component_builder=component_builder)
+    (trained, _, persisted_path) = train(
+        _config,
+        path=tmpdir.strpath,
+        data="./data/test/demo-rasa-noents.json",
+        component_builder=component_builder)
     assert trained.pipeline
     loaded = Interpreter.load(persisted_path, component_builder)
     assert loaded.pipeline
@@ -148,12 +143,12 @@ def test_train_model_noents(language, pipeline, component_builder, tmpdir):
 @pytest.mark.parametrize("language, pipeline", pipelines_for_tests())
 def test_train_model_multithread(language, pipeline, component_builder, tmpdir):
     _config = RasaNLUModelConfig({"pipeline": pipeline, "language": language})
-    (trained, _, persisted_path) = train.do_train(
-            _config,
-            path=tmpdir.strpath,
-            data=DEFAULT_DATA_PATH,
-            component_builder=component_builder,
-            num_threads=2)
+    (trained, _, persisted_path) = train(
+        _config,
+        path=tmpdir.strpath,
+        data=DEFAULT_DATA_PATH,
+        component_builder=component_builder,
+        num_threads=2)
     assert trained.pipeline
     loaded = Interpreter.load(persisted_path, component_builder)
     assert loaded.pipeline
@@ -165,20 +160,20 @@ def test_train_model_empty_pipeline(component_builder):
     # Should return an empty pipeline
     _config = utilities.base_test_conf(pipeline_template=None)
     with pytest.raises(ValueError):
-        train.do_train(
-                _config,
-                data=DEFAULT_DATA_PATH,
-                component_builder=component_builder)
+        train(
+            _config,
+            data=DEFAULT_DATA_PATH,
+            component_builder=component_builder)
 
 
 def test_train_named_model(component_builder, tmpdir):
     _config = utilities.base_test_conf("keyword")
-    (trained, _, persisted_path) = train.do_train(
-            _config,
-            path=tmpdir.strpath,
-            project="my_keyword_model",
-            data=DEFAULT_DATA_PATH,
-            component_builder=component_builder)
+    (trained, _, persisted_path) = train(
+        _config,
+        path=tmpdir.strpath,
+        project="my_keyword_model",
+        data=DEFAULT_DATA_PATH,
+        component_builder=component_builder)
     assert trained.pipeline
     normalized_path = os.path.dirname(os.path.normpath(persisted_path))
     # should be saved in a dir named after a project
@@ -186,13 +181,11 @@ def test_train_named_model(component_builder, tmpdir):
 
 
 def test_handles_pipeline_with_non_existing_component(component_builder):
-    _config = utilities.base_test_conf("spacy_sklearn")
+    _config = utilities.base_test_conf("pretrained_embeddings_spacy")
     _config.pipeline.append({"name": "my_made_up_component"})
     with pytest.raises(Exception) as execinfo:
-        train.do_train(
-                _config,
-                data=DEFAULT_DATA_PATH,
-                component_builder=component_builder)
+        train(_config, data=DEFAULT_DATA_PATH,
+              component_builder=component_builder)
     assert "Failed to find component" in str(execinfo.value)
 
 
